whatshap_logo_text.svg: Logo with editable text (Syntax font needs to be installed)
whatshap_logo.svg: Logo with text converted to paths
whatshap_logo_small.svg: Top part of logo only, without the text
